==> invoice-client-4.1.5-20200228.110036-65-sources.jar: com/xforceplus/seller/invoice/client/model/DetailInfo.java <==
package com.xforceplus.seller.invoice.client.model;


import java.math.BigDecimal;

public class DetailInfo {

    //单据明细id
    private Long salesBillItemId;

    //不含税金额
    private BigDecimal amountWithoutTax;

    //税额
    private BigDecimal taxAmount;

    //含税金额
    private BigDecimal amountWithTax;

    //价外含税折扣
    private BigDecimal outterDiscountWithTax;

    //价外不含税折扣
    private BigDecimal outterDiscountWithoutTax;

    //价外折扣税额
    private BigDecimal outterDiscountTax;

    //价内含税折扣
    private BigDecimal innerDiscountWithTax;

    //价内不含税折扣
    private BigDecimal innerDiscountWithoutTax;

    //价内折扣税额
    private BigDecimal innerDiscountTax;

    //价外预付卡含税金额
    private BigDecimal outterPrepayAmountWithTax;

    //价外预付卡不含税金额
    private BigDecimal outterPrepayAmountWithoutTax;

    //价外预付卡税额
    private BigDecimal outterPrepayAmountTax;

    //价内预付卡含税金额
    private BigDecimal innerPrepayAmountWithTax;

    //价内预付卡不含税金额
    private BigDecimal innerPrepayAmountWithoutTax;

    //价内预付卡税额
    private BigDecimal innerPrepayAmountTax;

    /**
     * 折扣不含税金额
     * 表 : inv_seller_pre_invoice_item
     * 对应字段 : discount_without_tax
     */
    private BigDecimal discountWithoutTax;

    /**
     * 折扣含税金额
     * 表 : inv_seller_pre_invoice_item
     * 对应字段 : discount_with_tax
     */
    private BigDecimal discountWithTax;

    /**
     * 折扣税额
     * 表 : inv_seller_pre_invoice_item
     * 对应字段 : discount_tax
     */
    private BigDecimal discountTax;

    //折扣率
    private BigDecimal discountRate;


    public Long getSalesBillItemId() {
        return salesBillItemId;
    }

    public void setSalesBillItemId(Long salesBillItemId) {
        this.salesBillItemId = salesBillItemId;
    }

    public BigDecimal getAmountWithoutTax() {
        return amountWithoutTax;
    }

    public void setAmountWithoutTax(BigDecimal amountWithoutTax) {
        this.amountWithoutTax = amountWithoutTax;
    }

    public BigDecimal getTaxAmount() {
        return taxAmount;
    }

    public void setTaxAmount(BigDecimal taxAmount) {
        this.taxAmount = taxAmount;
    }

    public BigDecimal getAmountWithTax() {
        return amountWithTax;
    }

    public void setAmountWithTax(BigDecimal amountWithTax) {
        this.amountWithTax = amountWithTax;
    }

    public BigDecimal getOutterDiscountWithTax() {
        return outterDiscountWithTax;
    }

    public void setOutterDiscountWithTax(BigDecimal outterDiscountWithTax) {
        this.outterDiscountWithTax = outterDiscountWithTax;
    }

    public BigDecimal getOutterDiscountWithoutTax() {
        return outterDiscountWithoutTax;
    }

    public void setOutterDiscountWithoutTax(BigDecimal outterDiscountWithoutTax) {
        this.outterDiscountWithoutTax = outterDiscountWithoutTax;
    }

    public BigDecimal getOutterDiscountTax() {
        return outterDiscountTax;
    }

    public void setOutterDiscountTax(BigDecimal outterDiscountTax) {
        this.outterDiscountTax = outterDiscountTax;
    }

    public BigDecimal getInnerDiscountWithTax() {
        return innerDiscountWithTax;
    }

    public void setInnerDiscountWithTax(BigDecimal innerDiscountWithTax) {
        this.innerDiscountWithTax = innerDiscountWithTax;
    }

    public BigDecimal getInnerDiscountWithoutTax() {
        return innerDiscountWithoutTax;
    }

    public void setInnerDiscountWithoutTax(BigDecimal innerDiscountWithoutTax) {
        this.innerDiscountWithoutTax = innerDiscountWithoutTax;
    }

    public BigDecimal getInnerDiscountTax() {
        return innerDiscountTax;
    }

    public void setInnerDiscountTax(BigDecimal innerDiscountTax) {
        this.innerDiscountTax = innerDiscountTax;
    }

    public BigDecimal getOutterPrepayAmountWithTax() {
        return outterPrepayAmountWithTax;
    }

    public void setOutterPrepayAmountWithTax(BigDecimal outterPrepayAmountWithTax) {
        this.outterPrepayAmountWithTax = outterPrepayAmountWithTax;
    }

    public BigDecimal getOutterPrepayAmountWithoutTax() {
        return outterPrepayAmountWithoutTax;
    }

    public void setOutterPrepayAmountWithoutTax(BigDecimal outterPrepayAmountWithoutTax) {
        this.outterPrepayAmountWithoutTax = outterPrepayAmountWithoutTax;
    }

    public BigDecimal getOutterPrepayAmountTax() {
        return outterPrepayAmountTax;
    }

    public void setOutterPrepayAmountTax(BigDecimal outterPrepayAmountTax) {
        this.outterPrepayAmountTax = outterPrepayAmountTax;
    }

    public BigDecimal getInnerPrepayAmountWithTax() {
        return innerPrepayAmountWithTax;
    }

    public void setInnerPrepayAmountWithTax(BigDecimal innerPrepayAmountWithTax) {
        this.innerPrepayAmountWithTax = innerPrepayAmountWithTax;
    }

    public BigDecimal getInnerPrepayAmountWithoutTax() {
        return innerPrepayAmountWithoutTax;
    }

    public void setInnerPrepayAmountWithoutTax(BigDecimal innerPrepayAmountWithoutTax) {
        this.innerPrepayAmountWithoutTax = innerPrepayAmountWithoutTax;
    }

    public BigDecimal getInnerPrepayAmountTax() {
        return innerPrepayAmountTax;
    }

    public void setInnerPrepayAmountTax(BigDecimal innerPrepayAmountTax) {
        this.innerPrepayAmountTax = innerPrepayAmountTax;
    }

    public BigDecimal getDiscountRate() {
        return discountRate;
    }

    public void setDiscountRate(BigDecimal discountRate) {
        this.discountRate = discountRate;
    }

    public BigDecimal getDiscountWithoutTax() {
        return discountWithoutTax;
    }

    public void setDiscountWithoutTax(BigDecimal discountWithoutTax) {
        this.discountWithoutTax = discountWithoutTax;
    }

    public BigDecimal getDiscountWithTax() {
        return discountWithTax;
    }

    public void setDiscountWithTax(BigDecimal discountWithTax) {
        this.discountWithTax = discountWithTax;
    }

    public BigDecimal getDiscountTax() {
        return discountTax;
    }

    public void setDiscountTax(BigDecimal discountTax) {
        this.discountTax = discountTax;
    }

    @Override
    public String toString() {
        return "DetailInfo{" +
                "salesBillItemId=" + salesBillItemId +
                ", amountWithoutTax=" + amountWithoutTax +
                ", taxAmount=" + taxAmount +
                ", amountWithTax=" + amountWithTax +
                ", outterDiscountWithTax=" + outterDiscountWithTax +
                ", outterDiscountWithoutTax=" + outterDiscountWithoutTax +
                ", outterDiscountTax=" + outterDiscountTax +
                ", innerDiscountWithTax=" + innerDiscountWithTax +
                ", innerDiscountWithoutTax=" + innerDiscountWithoutTax +
                ", innerDiscountTax=" + innerDiscountTax +
                ", outterPrepayAmountWithTax=" + outterPrepayAmountWithTax +
                ", outterPrepayAmountWithoutTax=" + outterPrepayAmountWithoutTax +
                ", outterPrepayAmountTax=" + outterPrepayAmountTax +
                ", innerPrepayAmountWithTax=" + innerPrepayAmountWithTax +
                ", innerPrepayAmountWithoutTax=" + innerPrepayAmountWithoutTax +
                ", innerPrepayAmountTax=" + innerPrepayAmountTax +
                ", discountRate=" + discountRate +
                ", discountWithoutTax=" + discountWithoutTax +
                ", discountTax=" + discountTax +
                ", discountWithTax=" + discountWithTax +
                '}';
    }
}

==> invoice-client-4.2.10-20250928.033045-2-sources.jar: com/xforceplus/seller/invoice/client/model/DetailInfo.java <==
package com.xforceplus.seller.invoice.client.model;


import lombok.Data;

import java.math.BigDecimal;

@Data
public class DetailInfo {

    //预制发票id
    private Long preInvoiceId;

    //单据id
    private Long salesBillId;

    //单据明细id
    private Long salesBillItemId;

    //不含税金额
    private BigDecimal amountWithoutTax;

    //税额
    private BigDecimal taxAmount;

    //含税金额
    private BigDecimal amountWithTax;

    //价外含税折扣
    private BigDecimal outterDiscountWithTax;

    //价外不含税折扣
    private BigDecimal outterDiscountWithoutTax;

    //价外折扣税额
    private BigDecimal outterDiscountTax;

    //价内含税折扣
    private BigDecimal innerDiscountWithTax;

    //价内不含税折扣
    private BigDecimal innerDiscountWithoutTax;

    //价内折扣税额
    private BigDecimal innerDiscountTax;

    //价外预付卡含税金额
    private BigDecimal outterPrepayAmountWithTax;

    //价外预付卡不含税金额
    private BigDecimal outterPrepayAmountWithoutTax;

    //价外预付卡税额
    private BigDecimal outterPrepayAmountTax;

    //价内预付卡含税金额
    private BigDecimal innerPrepayAmountWithTax;

    //价内预付卡不含税金额
    private BigDecimal innerPrepayAmountWithoutTax;

    //价内预付卡税额
    private BigDecimal innerPrepayAmountTax;

    /**
     * 折扣不含税金额
     * 表 : inv_seller_pre_invoice_item
     * 对应字段 : discount_without_tax
     */
    private BigDecimal discountWithoutTax;

    /**
     * 折扣含税金额
     * 表 : inv_seller_pre_invoice_item
     * 对应字段 : discount_with_tax
     */
    private BigDecimal discountWithTax;

    /**
     * 折扣税额
     * 表 : inv_seller_pre_invoice_item
     * 对应字段 : discount_tax
     */
    private BigDecimal discountTax;

    //折扣率
    private BigDecimal discountRate;
}
